@@ -46,13 +46,11 @@
  */
 #include <sys/time.h>
 #include <sys/types.h>
-#if defined(AIX) || defined(SYMBIAN)
+#if defined(AIX)
 #include <sys/select.h>
 #endif
 
-#ifndef SYMBIAN
 #define HAVE_NETINET_TCP_H
-#endif
 
 #define _PR_HAVE_O_APPEND
 
@@ -261,9 +259,7 @@ extern void		_MD_Wakeup_CPUs(void);
 #define _MD_CLEANUP_BEFORE_EXIT()
 #endif
 
-#ifndef IRIX
 #define _MD_EXIT(status)		_exit(status)
-#endif
 
 /************************************************************************/
 
@@ -302,7 +298,7 @@ extern PRIntervalTime   _PR_UNIX_TicksPerSecond(void);
 #define _MD_INTERVAL_PER_SEC		_PR_UNIX_TicksPerSecond
 #endif
 
-#ifdef HAVE_CLOCK_MONOTONIC
+#ifdef _PR_HAVE_CLOCK_MONOTONIC
 extern PRIntervalTime   _PR_UNIX_GetInterval2(void);
 extern PRIntervalTime   _PR_UNIX_TicksPerSecond2(void);
 #define _MD_INTERVAL_INIT()
