@@ -40,7 +40,7 @@ static char *compatible_version[] = {
     "4.10", "4.10.1", "4.10.2", "4.10.3", "4.10.4",
     "4.10.5", "4.10.6", "4.10.7", "4.10.8", "4.10.9",
     "4.10.10", "4.11", "4.12", "4.13", "4.14", "4.15",
-    "4.16", "4.17", "4.18", "4.19",
+    "4.16", "4.17", "4.18", "4.19", "4.20", "4.21",
     PR_VERSION
 };
 
@@ -56,8 +56,8 @@ static char *incompatible_version[] = {
     "3.0", "3.0.1",
     "3.1", "3.1.1", "3.1.2", "3.1.3",
     "3.5", "3.5.1",
-    "4.20.1",
-    "4.21", "4.21.1",
+    "4.22.1",
+    "4.23", "4.23.1",
     "10.0", "11.1", "12.14.20"
 };
 
